@@ -16,18 +16,15 @@ from geneticengine.algorithms.gp.operators.combinators import ParallelStep
 from geneticengine.algorithms.gp.operators.combinators import SequenceStep
 from geneticengine.algorithms.gp.operators.crossover import GenericCrossoverStep
 from geneticengine.algorithms.gp.operators.elitism import ElitismStep
-from geneticengine.algorithms.gp.operators.initializers import FullInitializer
-from geneticengine.algorithms.gp.operators.initializers import GrowInitializer
-from geneticengine.algorithms.gp.operators.initializers import (
-    InjectInitialPopulationWrapper,
-)
+from geneticengine.algorithms.gp.operators.initializers import StandardInitializer
 from geneticengine.algorithms.gp.operators.mutation import GenericMutationStep
 from geneticengine.algorithms.gp.operators.novelty import NoveltyStep
 from geneticengine.algorithms.gp.operators.selection import LexicaseSelection
 from geneticengine.algorithms.gp.operators.selection import TournamentSelection
 from geneticengine.algorithms.gp.operators.stop import (
+    AllFitnessTargetStoppingCriterium,
     AnyOfStoppingCriterium,
-    FitnessTargetStoppingCriterium,
+    SingleFitnessTargetStoppingCriterium,
     GenerationStoppingCriterium,
 )
 from geneticengine.algorithms.gp.operators.stop import TimeStoppingCriterium
@@ -36,13 +33,16 @@ from geneticengine.algorithms.gp.structure import PopulationInitializer
 from geneticengine.algorithms.gp.structure import StoppingCriterium
 from geneticengine.core.grammar import Grammar
 from geneticengine.core.evaluators import SequentialEvaluator
-from geneticengine.core.problems import Fitness, FitnessMultiObjective, FitnessSingleObjective, MultiObjectiveProblem
+from geneticengine.core.problems import MultiObjectiveProblem
 from geneticengine.core.problems import Problem
 from geneticengine.core.problems import SingleObjectiveProblem
 from geneticengine.core.problems import wrap_depth_minimization
 from geneticengine.core.random.sources import RandomSource
 from geneticengine.core.representations.api import Representation
 from geneticengine.core.representations.tree.operators import (
+    FullInitializer,
+    GrowInitializer,
+    InjectInitialPopulationWrapper,
     RampedHalfAndHalfInitializer,
 )
 from geneticengine.core.representations.tree.treebased import DefaultTBCrossover
@@ -177,14 +177,29 @@ class SimpleGP(GP):
         callbacks: list[Callback] | None = None,
         **kwargs,
     ):
-
         representation_class = representation or TreeBasedRepresentation
         representation_instance: Representation = representation_class(
             grammar,
             max_depth,
         )
-        if representation_class != TreeBasedRepresentation and initialization_method == "ramped":
-            initialization_method = "full"
+
+        population_initializer: PopulationInitializer
+        if representation_class != TreeBasedRepresentation:
+            population_initializer = StandardInitializer()
+        else:
+            population_initializer = {
+                "grow": GrowInitializer,
+                "full": FullInitializer,
+                "ramped": RampedHalfAndHalfInitializer,
+            }[
+                initialization_method
+            ]()  # type: ignore
+
+        if force_individual:
+            population_initializer = InjectInitialPopulationWrapper(
+                [representation_instance.phenotype_to_genotype(force_individual)],
+                population_initializer,
+            )
 
         processed_problem: Problem = self.wrap_depth(
             self.process_problem(
@@ -196,21 +211,6 @@ class SimpleGP(GP):
         )
         random_source = source_generator(seed)
 
-        population_initializer_class: type[PopulationInitializer] = {
-            "grow": GrowInitializer,
-            "full": FullInitializer,
-            "ramped": RampedHalfAndHalfInitializer,
-        }[
-            initialization_method
-        ]  # type: ignore
-        population_initializer: PopulationInitializer = population_initializer_class()
-
-        if force_individual:
-            population_initializer = InjectInitialPopulationWrapper(
-                [representation_instance.phenotype_to_genotype(force_individual)],
-                population_initializer,
-            )
-
         step: GeneticStep
 
         mutation_operator = representation_instance.get_mutation()
@@ -266,12 +266,12 @@ class SimpleGP(GP):
         else:
             stopping_criterium = GenerationStoppingCriterium(number_of_generations)
         if target_fitness is not None:
-            tg: Fitness
+            tg: StoppingCriterium
             if isinstance(processed_problem, SingleObjectiveProblem):
-                tg = FitnessSingleObjective(target_fitness)
+                tg = SingleFitnessTargetStoppingCriterium(target_fitness)
             else:
-                tg = FitnessMultiObjective(multiple_fitnesses=[target_fitness], fitness=target_fitness)
-            stopping_criterium = AnyOfStoppingCriterium(stopping_criterium, FitnessTargetStoppingCriterium(tg))
+                tg = AllFitnessTargetStoppingCriterium([target_fitness])
+            stopping_criterium = AnyOfStoppingCriterium(stopping_criterium, tg)
 
         self.callbacks: list[Callback] = []
         self.callbacks.extend(callbacks or [])
@@ -341,12 +341,12 @@ class SimpleGP(GP):
                 "This combination of parameters to define the problem is not valid",
             )
 
-    def wrap_depth(self, p: Problem, favor_less_complex_trees: bool = False):
-        if isinstance(p, SingleObjectiveProblem):
+    def wrap_depth(self, problem: Problem, favor_less_complex_trees: bool = False):
+        if isinstance(problem, SingleObjectiveProblem):
             if favor_less_complex_trees:
-                return wrap_depth_minimization(p)
+                return wrap_depth_minimization(problem)
             else:
-                return p
+                return problem
         else:
-            assert isinstance(p, MultiObjectiveProblem)
-            return p
+            assert isinstance(problem, MultiObjectiveProblem)
+            return problem
