@@ -11,7 +11,7 @@ class Evaluator(ABC):
         self.count = 0
 
     @abstractmethod
-    def eval(self, p: Problem, indivs: list[Individual[Any, Any]]):
+    def eval(self, problem: Problem, indivs: list[Individual[Any, Any]]):
         ...
 
     def register_evaluation(self):
@@ -20,16 +20,16 @@ class Evaluator(ABC):
     def get_count(self):
         return self.count
 
-    def eval_single(self, p: Problem, individual: Individual):
-        if not individual.has_fitness(p):
+    def eval_single(self, problem: Problem, individual: Individual):
+        if not individual.has_fitness(problem):
             phenotype = individual.get_phenotype()
-            individual.set_fitness(p, p.evaluate(phenotype=phenotype))
+            individual.set_fitness(problem, problem.evaluate(phenotype=phenotype))
             self.register_evaluation()
 
 
 class SequentialEvaluator(Evaluator):
     """Default evaluator for individuals, executes sequentially."""
 
-    def eval(self, p: Problem, indivs: list[Individual[Any, Any]]):
+    def eval(self, problem: Problem, indivs: list[Individual[Any, Any]]):
         for individual in indivs:
-            self.eval_single(p, individual)
+            self.eval_single(problem, individual)
