@@ -3,7 +3,7 @@ from pickle import _Pickler as StockPickler
 from typing import Any  # attr-defined: ignore
 from dill import register
 from geneticengine.algorithms.gp.individual import Individual
-from geneticengine.core.problems import Problem
+from geneticengine.core.problems import Fitness, Problem
 from geneticengine.core.evaluators import Evaluator
 from pathos.multiprocessing import ProcessingPool as Pool  # pyright: ignore
 
@@ -16,7 +16,12 @@ def save_abc(pickler, obj):
 class ParallelEvaluator(Evaluator):
     """Evaluates individuals in parallel, each time they are needed."""
 
-    def eval(self, p: Problem, indivs: list[Individual[Any, Any]]):
+    def eval(self, problem: Problem, indivs: list[Individual[Any, Any]]):
+        def mapper(ind: Individual) -> Fitness:
+            self.eval_single(problem, ind)
+            return ind.get_fitness(problem)
 
         with Pool(len(indivs)) as pool:
-            pool.map(lambda individual: self.eval_single(p, individual), indivs)
+            fitnesses = pool.map(mapper, indivs)
+            for i, f in zip(indivs, fitnesses):
+                i.set_fitness(problem, f)
