@@ -1,8 +1,6 @@
 from __future__ import annotations
 
 from typing import Any
-from typing import Dict
-from typing import List
 from typing import Protocol
 from typing import runtime_checkable
 
