@@ -1,10 +1,11 @@
 from __future__ import annotations
 
 from math import isinf
-from typing import Annotated
+from typing import Annotated, Any
 
 import numpy as np
 import pandas as pd
+from geneticengine.algorithms.callbacks.callback import Callback
 from sklearn.base import BaseEstimator
 from sklearn.base import TransformerMixin
 
@@ -62,11 +63,14 @@ class GeneticProgrammingClassifier(BaseEstimator, TransformerMixin):
         favor_less_complex_trees: bool = True,
         hill_climbing: bool = False,
         seed: int = 123,
+        scoring: Any = f1_score,
         # -----
         # As given in A Field Guide to GP, p.17, by Poli and Mcphee
         probability_mutation: float = 0.01,
         probability_crossover: float = 0.9,
         # -----
+        callbacks: list[Callback] | None = None,
+        parallel: bool = False,
     ):
         if nodes is None:
             nodes = [
@@ -97,23 +101,31 @@ class GeneticProgrammingClassifier(BaseEstimator, TransformerMixin):
         self.number_of_generations = number_of_generations
         self.probability_mutation = probability_mutation
         self.probability_crossover = probability_crossover
+        self.scoring = {None: scoring}
+        self.callbacks = callbacks
+        self.parallel_evaluation = parallel
 
-    def fit(self, X, y):
-        """Fits the classifier with data X and target y."""
-        if type(y) == pd.Series:
-            target = y.values
-        else:
-            target = y
-
+    def _preprocess_X(self, X):
         if type(X) == pd.DataFrame:
             feature_names = list(X.columns.values)
             data = X.values
         else:
             feature_names = [f"x{i}" for i in range(X.shape[1])]
             data = X
-        feature_indices = {}
-        for i, n in enumerate(feature_names):
-            feature_indices[n] = i
+        return data, feature_names
+
+    def _preprocess_y(self, y):
+        if type(y) == pd.Series:
+            return y.values
+        else:
+            return y
+
+    def fit(self, X, y):
+        """Fits the classifier with data X and target y."""
+        data, feature_names = self._preprocess_X(X)
+        target = self._preprocess_y(y)
+
+        feature_indices = {n: i for i, n in enumerate(feature_names)}
 
         Var.__init__.__annotations__["name"] = Annotated[str, VarRange(feature_names)]
         Var.feature_indices = feature_indices
@@ -129,12 +141,12 @@ class GeneticProgrammingClassifier(BaseEstimator, TransformerMixin):
                 variables[x] = data[:, i]
             y_pred = n.evaluate(**variables)
 
-            if type(y_pred) in [np.float64, int, float]:
-                """If n does not use variables, the output will be scalar."""
-                y_pred = np.full(len(target), y_pred)
+            y_pred = self.clean_prediction(y_pred, len(target))
+
             if y_pred.shape != (len(target),):
                 return -100000000
-            fitness = f1_score(y_pred, target)
+
+            fitness = self.scoring[None](target, y_pred)
             if isinf(fitness):
                 fitness = -100000000
             return fitness
@@ -156,6 +168,8 @@ class GeneticProgrammingClassifier(BaseEstimator, TransformerMixin):
             probability_crossover=self.probability_crossover,
             hill_climbing=self.hill_climbing,
             seed=self.seed,
+            callbacks=self.callbacks,
+            parallel_evaluation=self.parallel_evaluation,
         )
 
         ind = model.evolve()
@@ -182,6 +196,15 @@ class GeneticProgrammingClassifier(BaseEstimator, TransformerMixin):
             variables[x] = data[:, i]
         y_pred = self.evolved_phenotype.evaluate(**variables)
 
+        return self.clean_prediction(y_pred, len(X))
+
+    def clean_prediction(self, y_pred, target_size):
+        # Round values (like 0.1) to the nearest int, because it's a classification
+        y_pred = np.rint(y_pred)
+        if type(y_pred) in [np.float64, int, float]:
+            """If n does not use variables, the output will be scalar."""
+            y_pred = np.full(target_size, y_pred)
+
         return y_pred
 
 
